""" Constants for api.presalytics.io client """
HOST = "https://api.presaltyics.io"
OIDC_WELL_KNOWN = "https://auth.presalytics.io/auth/realms/presalytics/.well-known/openid-configuration"
OIDC_TOKEN = "https://auth.presalytics.io/auth/realms/presalytics/protocol/openid-connect/token"
PORT = 443
OIDC_AUTH_HOST = "https://auth.presalytics.io/auth/"
OIDC_AUTH_PORT = 443
REDIRECT_URI = "http://localhost:8052/"
OIDC_REALM = "presalytics"
DEFAULT_CLIENT_ID = "python-client"
TOKEN_FILE = "token.json"
LOCALHOST_SERVER = "127.0.0.1"
LOCALHOST_PORT = 8052

